import 'dart:async';
import 'dart:convert';

import 'package:cell_info/cellResponse.dart';
import 'package:cell_info/cell_info.dart';
import 'package:cell_info/models/common/cell_type.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  CellsResponse _cellsResponse;

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  String currentDBM = "";
  String currentCqi = "";
  String type = "";
  String mcc = "";

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    CellsResponse cellsResponse;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      String platformVersion = await CellInfo.getCellInfo;
      final body = json.decode(platformVersion);

      cellsResponse = CellsResponse.fromJson(body);

      CellType currentCellInFirstChip = cellsResponse.primaryCellList[0];
      if (currentCellInFirstChip.type == "LTE") {
        currentDBM =
            "LTE dbm = " + currentCellInFirstChip.lte.signalLTE.dbm.toString();

        currentCqi =
            "LTE cqi = " + currentCellInFirstChip.lte.signalLTE.cqi.toString();

        type = "LTE type = " + currentCellInFirstChip.lte.type.toString();

        type = "MCC = " + currentCellInFirstChip.lte.network.mcc.toString();
      } else if (currentCellInFirstChip.type == "NR") {
        currentDBM =
            "NR dbm = " + currentCellInFirstChip.nr.signalNR.dbm.toString();

        currentCqi =
            "NR cqi = " + currentCellInFirstChip.nr.signalNR.csiSinr.toString();

        type = "NR type = " + currentCellInFirstChip.nr.type.toString();

        type = "MCC = " + currentCellInFirstChip.nr.network.mcc.toString();
      } else if (currentCellInFirstChip.type == "WCDMA") {
        currentDBM = "WCDMA type = " +
            currentCellInFirstChip.wcdma.signalWCDMA.dbm.toString();

        currentCqi = "WCDMA cqi = " +
            currentCellInFirstChip.wcdma.signalWCDMA.ecio.toString();

        type = "WCDMA cqi = " + currentCellInFirstChip.wcdma.type.toString();

        mcc = "mcc = " + currentCellInFirstChip.wcdma.network.mcc.toString();

        print('currentDBM = ' + currentDBM);
        print('currentCqi = ' + currentCqi);
      } else if (currentCellInFirstChip.type == "GSM") {
        currentDBM =
            "GSM dbm = " + currentCellInFirstChip.gsm.signalGSM.dbm.toString();

        currentCqi =
            "GSM band = " + currentCellInFirstChip.gsm.bandGSM.toString();

        type = "Type = " + currentCellInFirstChip.gsm.type.toString();

        mcc = "MCC = " + currentCellInFirstChip.gsm.network.mcc.toString();

        print('currentDBM = ' + currentDBM);
        print('currentCqi = ' + currentCqi);
        print('currentType = ' + type);
        print('currentType = ' + mcc);
      }
    } on PlatformException {
      _cellsResponse = null;
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _cellsResponse = cellsResponse;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: _cellsResponse != null
            ? Center(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Text(
                        'currentDBM = ${currentDBM}\n primary = ${_cellsResponse.primaryCellList.length.toString()}'),
                    Text(
                        'currentCqi = ${currentCqi}\n primary = ${_cellsResponse.primaryCellList.length.toString()}'),
                    Text(type),
                    Text(mcc),
                  ],
                ),
              )
            : null,
      ),
    );
  }
}